@@ -101,10 +101,10 @@ def _root(instance, client, *_):
 
     if specs.get('quota:disk_read_bytes_sec'):
         device['limits.read'] = '{}MB'.format(
-            int(specs['quota:disk_read_bytes_sec']) / units.Mi)
+            int(specs['quota:disk_read_bytes_sec']) // units.Mi)
     if specs.get('quota:disk_write_bytes_sec'):
         device['limits.write'] = '{}MB'.format(
-            int(specs['quota:disk_write_bytes_sec']) / units.Mi)
+            int(specs['quota:disk_write_bytes_sec']) // units.Mi)
 
     minor_quota_defined = 'limits.write' in device or 'limits.read' in device
     if specs.get('quota:disk_total_iops_sec') and not minor_quota_defined:
@@ -112,7 +112,7 @@ def _root(instance, client, *_):
             specs['quota:disk_total_iops_sec'])
     if specs.get('quota:disk_total_bytes_sec') and not minor_quota_defined:
         device['limits.max'] = '{}MB'.format(
-            int(specs['quota:disk_total_bytes_sec']) / units.Mi)
+            int(specs['quota:disk_total_bytes_sec']) // units.Mi)
     if CONF.lxd.pool:
         extensions = client.host_info.get('api_extensions', [])
         if 'storage' in extensions:
@@ -155,24 +155,14 @@ def _network(instance, _, network_info, __):
     devices = {}
     for vifaddr in network_info:
         cfg = vif.get_config(vifaddr)
-        if 'bridge' in cfg:
-            key = str(cfg['bridge'])
-            devices[key] = {
-                'nictype': 'bridged',
-                'hwaddr': str(cfg['mac_address']),
-                'parent': str(cfg['bridge']),
-                'type': 'nic'
-            }
-        else:
-            key = 'unbridged'
-            devices[key] = {
-                'nictype': 'p2p',
-                'hwaddr': str(cfg['mac_address']),
-                'type': 'nic'
-            }
-        host_device = vif.get_vif_devname(vifaddr)
-        if host_device:
-            devices[key]['host_name'] = host_device
+        devname = vif.get_vif_devname(vifaddr)
+        key = devname
+        devices[key] = {
+            'nictype': 'physical',
+            'hwaddr': str(cfg['mac_address']),
+            'parent': vif.get_vif_internal_devname(vifaddr),
+            'type': 'nic'
+        }
 
         specs = instance.flavor.extra_specs
         # Since LXD does not implement average NIC IO and number of burst
@@ -186,7 +176,7 @@ def _network(instance, _, network_info, __):
         )
         if vif_inbound_limit:
             devices[key]['limits.ingress'] = '{}Mbit'.format(
-                vif_inbound_limit * units.k * 8 / units.M)
+                vif_inbound_limit * units.k * 8 // units.M)
 
         vif_outbound_limit = max(
             int(specs.get('quota:vif_outbound_average', 0)),
@@ -194,7 +184,7 @@ def _network(instance, _, network_info, __):
         )
         if vif_outbound_limit:
             devices[key]['limits.egress'] = '{}Mbit'.format(
-                vif_outbound_limit * units.k * 8 / units.M)
+                vif_outbound_limit * units.k * 8 // units.M)
     return devices
 
 
@@ -208,7 +198,7 @@ _DEVICE_FILTER_MAP = [
 def to_profile(client, instance, network_info, block_info, update=False):
     """Convert a nova flavor to a lxd profile.
 
-    Every instance container created via nova-lxd has a profiled by the
+    Every instance container created via nova-lxd has a profile by the
     same name. The profile is sync'd with the configuration of the container.
     When the instance container is deleted, so is the profile.
     """
